pub async fn collect_all_timers_dbus(
connection: &Connection,
config: &Config,
) -> Result<SystemdUnitStats>Expand description
Collect all timer stats via D-Bus and return them ready to merge into unit stats.
Used when unit stats were collected via varlink (which doesn’t yet expose timer
properties) so that timers.*, timer_persistent_units, and
timer_remain_after_elapse match the D-Bus output.